@@ -34,9 +34,12 @@
 		     set-buffer-multibyte
 		     find-non-ascii-charset-region char-charset
 		     mule-write-region-no-coding-system
-		     find-charset-region base64-decode-string
+		     find-charset-region 
 		     find-coding-systems-region get-charset-property
-		     coding-system-get w3-region))
+		     coding-system-get w3-region
+		     rmail-summary-exists rmail-select-summary
+		     rmail-update-summary
+		     ))
       (maybe-bind '(global-face-data
 		    mark-active transient-mark-mode mouse-selection-click-count
 		    mouse-selection-click-count-buffer buffer-display-table
@@ -66,8 +69,10 @@
 		 mm-copy-tree url-view-url w3-prepare-buffer
 		 mule-write-region-no-coding-system char-int
 		 annotationp delete-annotation make-image-specifier
-		 make-annotation base64-decode-string
-		 w3-do-setup w3-region base64-decode)))
+		 make-annotation 
+		 w3-do-setup w3-region
+		 rmail-summary-exists rmail-select-summary rmail-update-summary
+		 )))
 
 (setq load-path (cons "." load-path))
 (require 'custom)
